# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["RealtimeMcpToolExecutionErrorParam"]


class RealtimeMcpToolExecutionErrorParam(TypedDict, total=False):
    message: Required[str]

    type: Required[Literal["tool_execution_error"]]
