# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["RealtimeMcphttpError"]


class RealtimeMcphttpError(BaseModel):
    code: int

    message: str

    type: Literal["http_error"]
