# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .realtime_tools_config_union import RealtimeToolsConfigUnion

__all__ = ["RealtimeToolsConfig"]

RealtimeToolsConfig: TypeAlias = List[RealtimeToolsConfigUnion]
